X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/9b11752c4f9e1fd4b11ba3d184246267facb3ad3..9869c26285dc51d13607cddaa04f65ce983653a5:/include/wx/html/htmlwin.h
diff --git a/include/wx/html/htmlwin.h b/include/wx/html/htmlwin.h
index f9a87235e1..176cc9a46d 100644
--- a/include/wx/html/htmlwin.h
+++ b/include/wx/html/htmlwin.h
@@ -1,8 +1,7 @@
/////////////////////////////////////////////////////////////////////////////
-// Name: htmlwin.h
+// Name: wx/html/htmlwin.h
// Purpose: wxHtmlWindow class for parsing & displaying HTML
// Author: Vaclav Slavik
-// RCS-ID: $Id$
// Copyright: (c) 1999 Vaclav Slavik
// Licence: wxWindows licence
/////////////////////////////////////////////////////////////////////////////
@@ -195,7 +194,7 @@ protected:
/**
Called by HandleMouseClick when the user clicks on a cell.
- Default behavior is to call wxHtmlWindowInterface::OnLinkClicked()
+ Default behaviour is to call wxHtmlWindowInterface::OnLinkClicked()
if this cell corresponds to a hypertext link.
@param cell the cell the mouse is over
@@ -318,12 +317,14 @@ public:
// when/if we have CSS support we could add other possibilities...)
void SetBackgroundImage(const wxBitmap& bmpBg) { m_bmpBg = bmpBg; }
+#if wxUSE_CONFIG
// Saves custom settings into cfg config. it will use the path 'path'
// if given, otherwise it will save info into currently selected path.
// saved values : things set by SetFonts, SetBorders.
virtual void ReadCustomization(wxConfigBase *cfg, wxString path = wxEmptyString);
// ...
virtual void WriteCustomization(wxConfigBase *cfg, wxString path = wxEmptyString);
+#endif // wxUSE_CONFIG
// Goes to previous/next page (in browsing history)
// Returns true if successful, false otherwise
@@ -356,7 +357,7 @@ public:
// (depending on the information passed to SetRelatedFrame() method)
virtual void OnSetTitle(const wxString& title);
// Called when user clicked on hypertext link. Default behavior is to
// call LoadPage(loc)
virtual void OnLinkClicked(const wxHtmlLinkInfo& link);
@@ -400,8 +401,8 @@ protected:
// actual size of window. This method also setup scrollbars
void CreateLayout();
- void OnEraseBackground(wxEraseEvent& event);
void OnPaint(wxPaintEvent& event);
+ void OnEraseBackground(wxEraseEvent& event);
void OnSize(wxSizeEvent& event);
void OnMouseMove(wxMouseEvent& event);
void OnMouseDown(wxMouseEvent& event);
@@ -468,19 +469,19 @@ protected:
// is usually top one = all other cells are sub-cells of this one)
wxHtmlContainerCell *m_Cell;
// parser which is used to parse HTML input.
- // Each wxHtmlWindow has it's own parser because sharing one global
+ // Each wxHtmlWindow has its own parser because sharing one global
// parser would be problematic (because of reentrancy)
wxHtmlWinParser *m_Parser;
- // contains name of actualy opened page or empty string if no page opened
+ // contains name of actually opened page or empty string if no page opened
wxString m_OpenedPage;
// contains name of current anchor within m_OpenedPage
wxString m_OpenedAnchor;
- // contains title of actualy opened page or empty string if no
tag
+ // contains title of actually opened page or empty string if no tag
wxString m_OpenedPageTitle;
// class for opening files (file system)
wxFileSystem* m_FS;
- // frame in which page title should be displayed & number of it's statusbar
+ // frame in which page title should be displayed & number of its statusbar
// reserved for usage with this html window
wxFrame *m_RelatedFrame;
#if wxUSE_STATUSBAR
@@ -510,8 +511,13 @@ protected:
#endif // wxUSE_CLIPBOARD
private:
- // window content for double buffered rendering:
- wxBitmap *m_backBuffer;
+ // erase the window background using m_bmpBg or just solid colour if we
+ // don't have any background image
+ void DoEraseBackground(wxDC& dc);
+
+ // window content for double buffered rendering, may be invalid until it is
+ // really initialized in OnPaint()
+ wxBitmap m_backBuffer;
// background image, may be invalid
wxBitmap m_bmpBg;
@@ -539,23 +545,23 @@ private:
// if this FLAG is false, items are not added to history
bool m_HistoryOn;
- // a flag set if we need to erase background in OnPaint() (otherwise this
- // is supposed to have been done in OnEraseBackground())
- bool m_eraseBgInOnPaint;
+ // Flag used to communicate between OnPaint() and OnEraseBackground(), see
+ // the comments near its use.
+ bool m_isBgReallyErased;
// standard mouse cursors
static wxCursor *ms_cursorLink;
static wxCursor *ms_cursorText;
DECLARE_EVENT_TABLE()
- DECLARE_NO_COPY_CLASS(wxHtmlWindow)
+ wxDECLARE_NO_COPY_CLASS(wxHtmlWindow);
};
class WXDLLIMPEXP_FWD_HTML wxHtmlCellEvent;
-wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_COMMAND_HTML_CELL_CLICKED, wxHtmlCellEvent );
-wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_COMMAND_HTML_CELL_HOVER, wxHtmlCellEvent );
-wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_COMMAND_HTML_LINK_CLICKED, wxHtmlLinkEvent );
+wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_HTML_CELL_CLICKED, wxHtmlCellEvent );
+wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_HTML_CELL_HOVER, wxHtmlCellEvent );
+wxDECLARE_EXPORTED_EVENT( WXDLLIMPEXP_HTML, wxEVT_HTML_LINK_CLICKED, wxHtmlLinkEvent );
/*!
@@ -608,7 +614,7 @@ class WXDLLIMPEXP_HTML wxHtmlLinkEvent : public wxCommandEvent
public:
wxHtmlLinkEvent() {}
wxHtmlLinkEvent(int id, const wxHtmlLinkInfo &linkinfo)
- : wxCommandEvent(wxEVT_COMMAND_HTML_LINK_CLICKED, id)
+ : wxCommandEvent(wxEVT_HTML_LINK_CLICKED, id)
{
m_linkInfo = linkinfo;
}
@@ -634,12 +640,17 @@ typedef void (wxEvtHandler::*wxHtmlLinkEventFunction)(wxHtmlLinkEvent&);
wxEVENT_HANDLER_CAST(wxHtmlLinkEventFunction, func)
#define EVT_HTML_CELL_CLICKED(id, fn) \
- wx__DECLARE_EVT1(wxEVT_COMMAND_HTML_CELL_CLICKED, id, wxHtmlCellEventHandler(fn))
+ wx__DECLARE_EVT1(wxEVT_HTML_CELL_CLICKED, id, wxHtmlCellEventHandler(fn))
#define EVT_HTML_CELL_HOVER(id, fn) \
- wx__DECLARE_EVT1(wxEVT_COMMAND_HTML_CELL_HOVER, id, wxHtmlCellEventHandler(fn))
+ wx__DECLARE_EVT1(wxEVT_HTML_CELL_HOVER, id, wxHtmlCellEventHandler(fn))
#define EVT_HTML_LINK_CLICKED(id, fn) \
- wx__DECLARE_EVT1(wxEVT_COMMAND_HTML_LINK_CLICKED, id, wxHtmlLinkEventHandler(fn))
+ wx__DECLARE_EVT1(wxEVT_HTML_LINK_CLICKED, id, wxHtmlLinkEventHandler(fn))
+
+// old wxEVT_COMMAND_* constants
+#define wxEVT_COMMAND_HTML_CELL_CLICKED wxEVT_HTML_CELL_CLICKED
+#define wxEVT_COMMAND_HTML_CELL_HOVER wxEVT_HTML_CELL_HOVER
+#define wxEVT_COMMAND_HTML_LINK_CLICKED wxEVT_HTML_LINK_CLICKED
#endif // wxUSE_HTML
@@ -356,7 +357,7 @@ public:
// (depending on the information passed to SetRelatedFrame() method)
virtual void OnSetTitle(const wxString& title);
- // Called when user clicked on hypertext link. Default behavior is to
+ // Called when user clicked on hypertext link. Default behaviour is to
// call LoadPage(loc)
virtual void OnLinkClicked(const wxHtmlLinkInfo& link);